==> derby-0.0.10.tgz: package/lib/derby.browser.js <==
var Dom, History, Page, Route, View, modelHelper, racer;
racer = require('racer');
modelHelper = require('./modelHelper');
Dom = require('./Dom');
View = require('./View');
History = require('./History');
Route = require('express/lib/router/route');
Page = function() {};
Page.prototype = {
  render: function(ctx) {
    return this.view.render(this.model, ctx);
  },
  redirect: function(url) {
    if (url === 'back') {
      return this.history.back();
    }
    if (url === 'home') {
      url = '\\';
    }
    return this.history.replace(url, true);
  }
};
exports.createApp = function(appModule) {
  var appExports, dom, history, model, name, page, routes, template, view, _ref;
  appExports = appModule.exports;
  appExports.view = view = new View;
  routes = {};
  ['get', 'post', 'put', 'del'].forEach(function(method) {
    var queue;
    queue = routes[method] = [];
    return appExports[method] = function(pattern, callback) {
      return queue.push(new Route(method, pattern, callback));
    };
  });
  history = new History(routes, page = new Page);
  model = view.model = racer.model;
  dom = view.dom = new Dom(model, appExports, history);
  modelHelper.init(model, dom, view);
  appExports.ready = function(fn) {
    return racer.onready = function() {
      return fn(model);
    };
  };
  page.view = view;
  page.model = model;
  _ref = "$$templates$$";
  for (name in _ref) {
    template = _ref[name];
    view.make(name, template);
  }
  appModule.exports = function(idCount, paths, partialIds, aliases, depths, modelBundle, modelEvents, domEvents) {
    view._idCount = idCount;
    view._paths = paths;
    view._partialIds = partialIds;
    view._aliases = aliases;
    view._depths = depths;
    racer.init(modelBundle);
    model.__events.set(modelEvents);
    dom.init(domEvents);
    return appExports;
  };
  return appExports;
};

==> derby-0.1.0.tgz: package/lib/derby.browser.js <==
var Dom, History, Page, Route, View, modelHelper, racer;
racer = require('racer');
modelHelper = require('./modelHelper');
Dom = require('./Dom');
View = require('./View');
History = require('./History');
Route = require('express/lib/router/route');
Page = function() {};
Page.prototype = {
  render: function(ctx) {
    return this.view.render(this.model, ctx);
  },
  redirect: function(url) {
    if (url === 'back') {
      return this.history.back();
    }
    if (url === 'home') {
      url = '\\';
    }
    return this.history.replace(url, true);
  }
};
exports.createApp = function(appModule) {
  var appExports, dom, history, model, name, page, routes, template, view, _ref;
  appExports = appModule.exports;
  appExports.view = view = new View;
  routes = {};
  ['get', 'post', 'put', 'del'].forEach(function(method) {
    var queue;
    queue = routes[method] = [];
    return appExports[method] = function(pattern, callback) {
      return queue.push(new Route(method, pattern, callback));
    };
  });
  history = new History(routes, page = new Page);
  model = view.model = racer.model;
  dom = view.dom = new Dom(model, appExports, history);
  modelHelper.init(model, dom, view);
  appExports.ready = function(fn) {
    return racer.onready = function() {
      return fn(model);
    };
  };
  page.view = view;
  page.model = model;
  _ref = "$$templates$$";
  for (name in _ref) {
    template = _ref[name];
    view.make(name, template);
  }
  appModule.exports = function(idCount, paths, aliases, pathMapCount, pathMapIds, modelBundle, modelEvents, domEvents) {
    view._idCount = idCount;
    view._paths = paths;
    view._aliases = aliases;
    model.__pathMap.init(pathMapCount, pathMapIds);
    model.__events.set(modelEvents);
    dom.init(domEvents);
    racer.init(modelBundle);
    return appExports;
  };
  return appExports;
};
